@@ -2,19 +2,19 @@ package App::githook::perltidy::pre_commit;
 use strict;
 use warnings;
 use feature 'state';
-use App::githook::perltidy::pre_commit_CI
-  isa => 'App::githook::perltidy',
-  has => {};
-use OptArgs2::StatusLine '$status', '$v_status', 'RS';
+use parent 'App::githook::perltidy';
+use File::Basename;
+use File::Copy;
+use OptArgs2::StatusLine;
 use Path::Tiny;
 
-our $VERSION = '1.0.0';
+our $VERSION = '1.0.0_1';
 
-our $temp_dir;
+our ( $line, $prefix, $verbose, $prefix2, $temp_dir );
 
 sub sys {
     my $self = shift;
-    $v_status = join( ' ', map { defined $_ ? $_ : '*UNDEF*' } @_ ) . "\n";
+    $verbose = join( ' ', map { defined $_ ? $_ : '*UNDEF*' } @_ ) . "\n";
     system(@_) == 0 or Carp::croak "@_ failed: $?";
 }
 
@@ -24,51 +24,57 @@ sub tmp_sys {
     $self->sys(@_);
 }
 
-sub tidy_perl {
+sub perl_tidy {
     my $self     = shift;
-    my $tmp_file = shift || die 'tidy_perl($TMP_FILE, $file)';
-    my $file     = shift || die 'tidy_perl($tmp_file, $FILE)';
+    my $tmp_file = shift || die 'perl_tidy($TMP_FILE, $file)';
+    my $file     = shift || die 'perl_tidy($tmp_file, $FILE)';
     my $where    = shift;
 
-    state $req = do {
-        no strict 'refs';
-        if ( $self->sweetened ) {
+    die ".perltidyrc not in repository.\n" unless $self->{perltidyrc};
+
+    $verbose = "perltidy $file ($where)\n" if $self->{opts}->{verbose};
+
+    state $junk = do {
+        if ( $self->{sweetened} ) {
             require Perl::Tidy::Sweetened;
-            *perltidy = \&Perl::Tidy::Sweetened::perltidy;
+            $self->{perltidy} = \&Perl::Tidy::Sweetened::perltidy;
         }
         else {
             require Perl::Tidy;
-            *perltidy = \&Perl::Tidy::perltidy;
+            $self->{perltidy} = \&Perl::Tidy::perltidy;
         }
+        undef;
     };
 
-    $status = "(perltidy) ($where)";
-
     my $errormsg;
-    my $error = perltidy(
+
+    my $error = $self->{perltidy}->(
         argv       => [ qw{-nst -b -bext=/}, "$tmp_file" ],
         errorfile  => \$errormsg,
-        perltidyrc => $self->perltidyrc->stringify,
+        perltidyrc => $self->{perltidyrc}->stringify,
     );
 
     if ( length($errormsg) ) {
-        $status .= ":\n";
+        $line .= ":\n";
         die $errormsg;
     }
     elsif ($error) {
-        $status .= ":\n";
+        $line .= ":\n";
         die "An unknown perltidy error occurred.";
     }
 }
 
-sub tidy_pod {
+sub pod_tidy {
     my $self     = shift;
-    my $tmp_file = shift || die 'tidy_pod($TMP_FILE, $file)';
-    my $file     = shift || die 'tidy_pod($tmp_file, $FILE)';
+    my $tmp_file = shift || die 'pod_tidy($TMP_FILE, $file)';
+    my $file     = shift || die 'pod_tidy($tmp_file, $FILE)';
     my $where    = shift;
 
-    state $req = require Pod::Tidy;
-    $status = "(podtidy) ($where)";
+    die ".podtidy-opts not in repository.\n" unless $self->{podtidyrc};
+
+    state $junk = require Pod::Tidy;
+
+    $verbose = "podtidy $file ($where)\n" if $self->{opts}->{verbose};
 
     Pod::Tidy::tidy_files(
         files     => [$tmp_file],
@@ -77,36 +83,42 @@ sub tidy_pod {
         inplace   => 1,
         nobackup  => 1,
         columns   => 72,
-        %{ $self->podtidyrc_opts },
+        %{ $self->{podtidyrc_opts} },
     );
 }
 
-sub critic_perl {
+sub perl_critic {
     my $self     = shift;
-    my $tmp_file = shift || die 'critic_perl($TMP_FILE, $file)';
-    my $file     = shift || die 'critic_perl($tmp_file, $FILE)';
+    my $tmp_file = shift || die 'perl_critic($TMP_FILE, $file)';
+    my $file     = shift || die 'perl_critic($tmp_file, $FILE)';
     my $where    = shift;
 
-    state $req = require Perl::Critic;
-    $status = "(perlcritic) ($where)";
+    die ".perlcriticrc not in repository.\n" unless $self->{perlcriticrc};
+
+    state $junk = require Perl::Critic;
+
+    $verbose = "perlcritic $file ($where)\n" if $self->{opts}->{verbose};
 
     my @violations =
-      Perl::Critic::critique( { -profile => $self->perlcriticrc->stringify },
+      Perl::Critic::critique( { -profile => $self->{perlcriticrc}->stringify },
         $tmp_file->stringify );
 
     if (@violations) {
-        $status .= ":\n";
+        $line .= ":\n";
         die join( '', @violations );
     }
 }
 
-sub convert_readme {
+sub readme_from {
     my $self = shift;
-    my $file = shift || die 'convert_readme($FILE)';
+    my $file = shift || die 'readme_from($FILE)';
 
-    $status = '-> README';
+    $verbose = $file->basename . " -> README\n" if $self->{opts}->{verbose};
 
-    my $width = $self->podtidyrc_opts->{columns} // 72;
+    my $width =
+      exists $self->{podtidy_opts}->{columns}
+      ? $self->{podtidy_opts}->{columns}
+      : 72;
 
     require Pod::Text;
     Pod::Text->new( sentence => 0, width => $width )
@@ -122,16 +134,19 @@ sub run {
     my @perlfiles = ();
     my %partial   = ();
 
-    untie $v_status unless $self->verbose;
+    OptArgs2::StatusLine::make_line_prefix( $line,    $prefix );
+    OptArgs2::StatusLine::make_line_prefix( $verbose, $prefix2 )
+      if $self->{opts}->{verbose};
+
+    $prefix = $prefix2 = basename($0) . ': ';
 
     return if $ENV{NO_GITHOOK_PERLTIDY};
     $temp_dir = Path::Tiny->tempdir('githook-perltidy-XXXXXXXX');
 
-    $v_status = "TMP=$temp_dir\n";
+    $verbose = "TMP=$temp_dir\n";
 
     my @index;
     my $force_readme = 0;
-    my $readme_from  = $self->readme_from // '';
 
     # Use the -z flag to get clean filenames with no escaping or quoting
     # "lines" are separated with NUL, so set input record separator
@@ -149,19 +164,19 @@ sub run {
             $partial{$file} = $wtree eq 'M';
 
             $force_readme++ if $file eq '.readme_from';
-            $force_readme-- if $file eq $readme_from;
+            $force_readme-- if $file eq $self->{readme_from};
         }
     }
 
     if ( $force_readme > 0 ) {
-        $v_status = "force .readme_from " . $self->readme_from . "\n"
-          if $self->verbose;
-        push( @index, $self->readme_from );
+        $verbose = "force .readme_from $self->{readme_from}\n"
+          if $self->{opts}->{verbose};
+        push( @index, $self->{readme_from} );
     }
 
     unless (@index) {
-        $status = "(0)\n";
-        return 0;
+        $line = "(0)\n";
+        exit 0;
     }
 
     $self->tmp_sys( qw/git checkout-index/, @index );
@@ -174,90 +189,92 @@ sub run {
               or $first =~ m/^#!.*\.plenv/;
         }
 
-        push( @perlfiles, path($file) );
+        push( @perlfiles, $file );
     }
 
     unless (@perlfiles) {
-        $status = "files touched: 0\n";
+        $line = "files touched: 0\n";
         exit 0;
     }
 
-    $v_status = "no .podtidy-opts - skipping podtidy calls\n"
-      if not $self->podtidyrc;
+    $verbose = "no .podtidy-opts - skipping podtidy calls\n"
+      if $self->{opts}->{verbose} and not $self->{podtidyrc};
 
     my $i     = 1;
     my $total = scalar @perlfiles;
     foreach my $file (@perlfiles) {
-        my $base = $file->basename;
-        $status = $v_status = '';
-        local $status = local $v_status = "$status ($i/$total) $base " . RS;
+        local $prefix  = "$prefix" . '(' . $i . '/' . $total . ') ';
+        local $prefix2 = "$prefix2" . '(' . $i . '/' . $total . ') ';
 
         my $tmp_file = $temp_dir->child($file);
 
         # If the README conversion is forced then we don't need to tidy
         # the source file
-        if ( $file eq $readme_from and $force_readme > 0 ) {
-            $self->convert_readme($tmp_file);
+        if ( $file eq $self->{readme_from} and $force_readme > 0 ) {
+            $self->readme_from($tmp_file);
             $force_readme--;
             next;
         }
 
         # Critique first to avoid unecessary tidying
-        if ( $self->perlcriticrc ) {
-            $self->critic_perl( $tmp_file, $file, 'INDEX' );
+        if ( $self->{perlcriticrc} ) {
+            $line = $file . ' (perlcritic)';
+            $self->perl_critic( $tmp_file, $file, 'INDEX' );
         }
 
         unless ( $file =~ m/\.pod$/i ) {
-            $self->tidy_perl( $tmp_file, $file, 'INDEX' );
+            $line = $file . ' (perltidy)';
+            $self->perl_tidy( $tmp_file, $file, 'INDEX' );
         }
 
-        if ( $self->podtidyrc ) {
-            $self->tidy_pod( $tmp_file, $file, 'INDEX' );
+        if ( $self->{podtidyrc} ) {
+            $line = $file . ' (podtidy)';
+            $self->pod_tidy( $tmp_file, $file, 'INDEX' );
         }
 
-        if ( $file eq $readme_from ) {
-            $self->convert_readme($tmp_file);
+        if ( $file eq $self->{readme_from} ) {
+            $self->readme_from($tmp_file);
         }
 
         $i++;
     }
 
-    warn "Failed to convert to README: $readme_from\n"
+    warn "Failed to convert to README: $self->{force_readme}\n"
       unless $force_readme <= 0;
 
     $self->tmp_sys( qw/git add /, @perlfiles );
 
     $i = 1;
     foreach my $file (@perlfiles) {
-        my $base = $file->basename;
-        $status = $v_status = '';
-        local $status = local $v_status = "$status ($i/$total) $base " . RS;
+        local $prefix  = "$prefix" . '(' . $i . '/' . $total . ') ';
+        local $prefix2 = "$prefix2" . '(' . $i . '/' . $total . ') ';
 
         my $tmp_file = $temp_dir->child($file);
 
         # Redo the whole thing again for partially modified files
         if ( $partial{$file} ) {
-            $v_status = "copy to TMP\n";
-            $file->copy($tmp_file);
+            $verbose = "copy $file TMP\n"
+              if $self->{opts}->{verbose};
+            copy $file, $tmp_file;
 
             unless ( $file =~ m/\.pod$/i ) {
-                $self->tidy_perl( $tmp_file, $file, 'WORK_TREE' );
+                $line = $file . ' (perltidy cleanup)';
+                $self->perl_tidy( $tmp_file, $file, 'WORK_TREE' );
             }
 
-            if ( $self->podtidyrc ) {
-                $self->tidy_pod( $tmp_file, $file, 'INDEX' );
-                $self->tidy_pod( $tmp_file, $file, 'WORK_TREE' );
+            if ( $self->{podtidyrc} ) {
+                $line = $file . ' (podtidy cleanup)';
+                $self->pod_tidy( $tmp_file, $file, 'INDEX' );
+                $self->pod_tidy( $tmp_file, $file, 'WORK_TREE' );
             }
         }
 
         # Move the tidied file back to the real working directory
-        $status = 'move TMP to REPO';
-        my $mtime = $file->stat->mtime;
-        $tmp_file->move($file);
-        utime $file->stat->atime, $mtime, $file;
+        $line = $file . ' (mv)';
+        move $tmp_file, $file;
     }
 
-    $status = "files touched: $total\n";
+    $line = "files touched: $total\n";
 }
 
 1;
@@ -269,7 +286,7 @@ App::githook::perltidy::pre_commit - git pre-commit hook
 
 =head1 VERSION
 
-1.0.0 (2022-10-14)
+1.0.0_1 (2022-04-10)
 
 =head1 SEE ALSO
 
@@ -288,4 +305,3 @@ under the terms of the GNU General Public License as published by the
 Free Software Foundation; either version 3 of the License, or (at your
 option) any later version.
 
-
